@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2017 Aurimas Cernius
+ * Copyright (C) 2011-2018 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -63,6 +63,7 @@
 #include "debug.hpp"
 #include "actionmanager.hpp"
 #include "iconmanager.hpp"
+#include "utils.hpp"
 
 namespace gnote {
 
@@ -88,6 +89,9 @@ namespace gnote {
     register_main_window_action("enable-bullets", &Glib::Variant<bool>::variant_type(), true);
     register_main_window_action("increase-indent", NULL, true);
     register_main_window_action("decrease-indent", NULL, true);
+
+    signal_build_main_window_search_popover.connect(sigc::mem_fun(*this, &ActionManager::add_app_menu_new_section));
+    signal_build_main_window_search_popover.connect(sigc::mem_fun(*this, &ActionManager::add_app_menu_trailing_sections));
   }
 
 
@@ -99,7 +103,6 @@ namespace gnote {
     add_app_action("about");
     add_app_action("help-contents");
     add_app_action("help-shortcuts");
-    add_app_action("quit");
   }
 
   Glib::RefPtr<Gio::SimpleAction> ActionManager::get_app_action(const Glib::ustring & name) const
@@ -131,56 +134,10 @@ namespace gnote {
   {
     add_app_menu_item(APP_ACTION_NEW, 100, _("_New Note"), "app.new-note");
     add_app_menu_item(APP_ACTION_NEW, 200, _("New _Window"), "app.new-window");
-    add_app_menu_item(APP_ACTION_MANAGE, 100, _("_Preferences"), "app.show-preferences");
+    add_app_menu_item(APP_ACTION_LAST, 50, _("_Preferences"), "app.show-preferences");
     add_app_menu_item(APP_ACTION_LAST, 100, _("_Shortcuts"), "app.help-shortcuts");
     add_app_menu_item(APP_ACTION_LAST, 150, _("_Help"), "app.help-contents");
-    add_app_menu_item(APP_ACTION_LAST, 200, _("_About"), "app.about");
-    add_app_menu_item(APP_ACTION_LAST, 300, _("_Quit"), "app.quit");
-  }
-
-  Glib::RefPtr<Gio::Menu> ActionManager::get_app_menu() const
-  {
-    Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
-
-    int pos = 0;
-    Glib::RefPtr<Gio::Menu> section = make_app_menu_section(APP_ACTION_NEW);
-    if(section) {
-      menu->insert_section(pos++, section);
-    }
-
-    section = make_app_menu_section(APP_ACTION_MANAGE);
-    if(section) {
-      menu->insert_section(pos++, section);
-    }
-
-    section = make_app_menu_section(APP_ACTION_LAST);
-    if(section) {
-      menu->insert_section(pos++, section);
-    }
-
-    return menu;
-  }
-
-  Glib::RefPtr<Gio::Menu> ActionManager::make_app_menu_section(int sec) const
-  {
-    std::pair<AppMenuItemMultiMap::const_iterator, AppMenuItemMultiMap::const_iterator>
-    range = m_app_menu_items.equal_range(sec);
-
-    Glib::RefPtr<Gio::Menu> section;
-    if(range.first != m_app_menu_items.end()) {
-      std::vector<const AppMenuItem*> menu_items;
-      for(AppMenuItemMultiMap::const_iterator iter = range.first; iter != range.second; ++iter) {
-        menu_items.push_back(&iter->second);
-      }
-      std::sort(menu_items.begin(), menu_items.end(), AppMenuItem::ptr_comparator());
-
-      section = Gio::Menu::create();
-      for(std::vector<const AppMenuItem*>::iterator iter = menu_items.begin(); iter != menu_items.end(); ++iter) {
-        section->append((*iter)->label, (*iter)->action_def);
-      }
-    }
-
-    return section;
+    add_app_menu_item(APP_ACTION_LAST, 200, _("_About Gnote"), "app.about");
   }
 
   void ActionManager::register_main_window_action(const Glib::ustring & action, const Glib::VariantType *state_type, bool modifying)
@@ -232,4 +189,39 @@ namespace gnote {
     return cbacks;
   }
 
+  bool ActionManager::add_app_menu_section(std::map<int, Gtk::Widget*> & widgets, int & order, int section)
+  {
+    std::pair<AppMenuItemMultiMap::const_iterator, AppMenuItemMultiMap::const_iterator>
+    range = m_app_menu_items.equal_range(section);
+
+    if(range.first != m_app_menu_items.end()) {
+      for(AppMenuItemMultiMap::const_iterator iter = range.first; iter != range.second; ++iter) {
+        widgets.insert(std::make_pair(order++, utils::create_popover_button(iter->second.action_def, iter->second.label)));
+      }
+
+      return true;
+    }
+
+    return false;
+  }
+
+  void ActionManager::add_app_menu_new_section(std::map<int, Gtk::Widget*> & widgets)
+  {
+    int order = 0;
+    if(add_app_menu_section(widgets, order, APP_ACTION_NEW)) {
+      // end section
+      widgets[order] = NULL;
+    }
+  }
+
+  void ActionManager::add_app_menu_trailing_sections(std::map<int, Gtk::Widget*> & widgets)
+  {
+    int order = 100000;
+    if(add_app_menu_section(widgets, order, APP_ACTION_MANAGE)) {
+      // end section
+      widgets[order] = NULL;
+    }
+    add_app_menu_section(widgets, order, APP_ACTION_LAST);
+  }
+
 }
